@@ -1,5 +1,2 @@
-# coding=utf-8
 """CMIS (REST aka AtomPub bind) interface to the document repository."""
-from __future__ import absolute_import
-
 from . import atompub  # noqa
