@@ -1,7 +1,15 @@
 from pathlib import Path
 
-from flask import current_app, flash, jsonify, make_response, redirect, \
-    render_template, request, url_for
+from flask import (
+    current_app,
+    flash,
+    jsonify,
+    make_response,
+    redirect,
+    render_template,
+    request,
+    url_for,
+)
 from flask_babel import gettext as _
 from flask_login import current_user
 from sqlalchemy import func
