@@ -51,7 +51,7 @@ class AbilianSBE:
         # sbe static assets
         app.add_static_url("abilian/sbe", STATIC_DIR, endpoint="abilian_sbe_static")
         app.extensions["webassets"].append_path(
-            STATIC_DIR, app.static_url_path + "/abilian/sbe"
+            STATIC_DIR, f"{app.static_url_path}/abilian/sbe"
         )
 
         app.register_asset("js", *JS)
