@@ -3,16 +3,16 @@ define("SBEFolderListingSetup", [
   "jquery",
   "jquery.dataTables",
   "bootbox",
-], function(Abilian, $, jqDT, bootbox) {
+], (Abilian, $, jqDT, bootbox) => {
   "use strict";
   function setupFolderListing() {
-    $.fn.dataTableExt.afnFiltering.push(function(oSettings, aData, iDataIndex) {
-      var filter_value = $("#filter").val();
-      var row_text = aData[2].trim();
+    $.fn.dataTableExt.afnFiltering.push((oSettings, aData, iDataIndex) => {
+      const filter_value = $("#filter").val();
+      const row_text = aData[2].trim();
       return row_text.match(new RegExp(filter_value, "i"));
     });
 
-    var dtParams = {
+    const dtParams = {
       aoColumns: [
         { asSorting: [], sWidth: "1%" },
         { bVisible: false, sType: "cmistype" },
@@ -61,11 +61,11 @@ define("SBEFolderListingSetup", [
       iDisplayLength: 50,
       sDom: "lrtip",
     };
-    var objectsTable = $("#objects-table").dataTable(dtParams);
+    const objectsTable = $("#objects-table").dataTable(dtParams);
 
     /* on page reload datatable keep previously filtered rows. Force
          refilter with current filter value */
-    var filter = $("#filter");
+    const filter = $("#filter");
     objectsTable.fnFilter(filter.val());
 
     /* check / uncheck all */
@@ -73,18 +73,18 @@ define("SBEFolderListingSetup", [
       $("input[name='object-selected']").prop("checked", checked);
     }
 
-    $("a[href='#select-all']").click(function(e) {
+    $("a[href='#select-all']").click((e) => {
       setSelected(true);
       e.preventDefault();
     });
 
-    $("a[href='#unselect-all']").click(function(e) {
+    $("a[href='#unselect-all']").click((e) => {
       setSelected(false);
       e.preventDefault();
     });
 
     /* enter key */
-    filter.bind("keypress", function(e) {
+    filter.bind("keypress", function (e) {
       if (e.keyCode === 13) {
         /* let return key for refilter */
         objectsTable.fnFilter(this.value);
@@ -92,7 +92,7 @@ define("SBEFolderListingSetup", [
       }
     });
 
-    filter.bind("keyup", function(e) {
+    filter.bind("keyup", function (e) {
       if (e.keyCode === 13) {
         e.preventDefault();
       }
@@ -102,27 +102,25 @@ define("SBEFolderListingSetup", [
     /* actions */
     function onClickDelete(e) {
       e.preventDefault();
-      var $button = $(this);
-      var buttonForm = $(this.form);
+      const $button = $(this);
+      const buttonForm = $(this.form);
       /* eslint-disable-next-line no-undef */
-      var msg = CONFIG.deleteConfirmMsg;
-      var elements = $(document.forms["folder-listing"])
+      let msg = CONFIG.deleteConfirmMsg;
+      const elements = $(document.forms["folder-listing"])
         .find('input[name="object-selected"]:checked')
         .closest("td")
         .next("td");
-      var elList = $("<ul />").attr({ class: "folder-items" });
+      const elList = $("<ul />").attr({ class: "folder-items" });
 
-      elements.each(function() {
-        var li = $("<li />").html($(this).html());
+      elements.each(function () {
+        const li = $("<li />").html($(this).html());
         elList.append(li);
       });
-      msg += $("<div />")
-        .append(elList)
-        .html();
+      msg += $("<div />").append(elList).html();
 
-      bootbox.confirm(msg, function(confirm) {
+      bootbox.confirm(msg, (confirm) => {
         if (confirm) {
-          var actionVal = $("<input />", {
+          const actionVal = $("<input />", {
             type: "hidden",
             name: "action",
             value: $button.attr("value"),
@@ -136,22 +134,22 @@ define("SBEFolderListingSetup", [
     $('button.btn-danger[value="delete"]').click(onClickDelete);
 
     /* Move file functions */
-    var moveFileFillListing = function(modal, folder_url) {
-      var tbody = modal.find("tbody");
-      var breadcrumbs = modal.find("ul.breadcrumb");
+    const moveFileFillListing = (modal, folder_url) => {
+      const tbody = modal.find("tbody");
+      const breadcrumbs = modal.find("ul.breadcrumb");
 
       $.ajax({
         type: "GET",
         dataType: "json",
         url: folder_url,
         cache: false,
-        success: function(data) {
-          var bc = $(data.breadcrumbs);
+        success: function (data) {
+          const bc = $(data.breadcrumbs);
           breadcrumbs.empty();
 
-          bc.each(function() {
-            var li = $("<li />");
-            var link = $("<a>" + this.title + "</a>")
+          bc.each(function () {
+            const li = $("<li />");
+            const link = $("<a>" + this.title + "</a>")
               .attr("href", this.url)
               .attr("data-id", this.id);
 
@@ -159,13 +157,13 @@ define("SBEFolderListingSetup", [
             li.appendTo(breadcrumbs);
           });
 
-          var folders = $(data.folders);
+          const folders = $(data.folders);
           tbody.empty();
 
-          folders.each(function() {
-            var tr = $("<tr />");
-            var td = $("<td />");
-            var link = $("<a>" + this.title + "</a>")
+          folders.each(function () {
+            const tr = $("<tr />");
+            const td = $("<td />");
+            const link = $("<a>" + this.title + "</a>")
               .attr("href", this.url)
               .attr("data-id", this.id);
 
@@ -175,8 +173,8 @@ define("SBEFolderListingSetup", [
           });
 
           /** @type {boolean} */
-          var folderSelectable = data["current_folder_selectable"];
-          var button = $("#modal-move-button-submit");
+          const folderSelectable = data.current_folder_selectable;
+          const button = $("#modal-move-button-submit");
           button.attr("disabled", !folderSelectable);
           if (!folderSelectable ^ button.hasClass("disabled")) {
             button.toggleClass("disabled");
@@ -185,40 +183,41 @@ define("SBEFolderListingSetup", [
       });
     };
 
-    $(document).on("click", "#modal-move-files-directory-listing a", function(
-      e
-    ) {
-      var self = $(this);
-      var folder_id = self.attr("data-id");
-      var modal = $("#modal-move-files");
-      var url = self.attr("href");
+    $(document).on(
+      "click",
+      "#modal-move-files-directory-listing a",
+      function (e) {
+        const self = $(this);
+        const folder_id = self.attr("data-id");
+        const modal = $("#modal-move-files");
+        const url = self.attr("href");
 
-      modal.find('input[name="target-folder"]').attr("value", folder_id);
+        modal.find('input[name="target-folder"]').attr("value", folder_id);
 
-      moveFileFillListing(modal, url);
-      e.preventDefault();
-    });
+        moveFileFillListing(modal, url);
+        e.preventDefault();
+      }
+    );
 
-    $("#modal-move-files").on("show.bs.modal", function() {
-      var modal = $(this);
-      var listing_form = $(document.forms["folder-listing"]);
-      var elements = listing_form.find("input[name='object-selected']:checked");
-      var footer_inputs = $("#modal-move-files-inputs");
+    $("#modal-move-files").on("show.bs.modal", function () {
+      const modal = $(this);
+      const listing_form = $(document.forms["folder-listing"]);
+      const elements = listing_form.find(
+        "input[name='object-selected']:checked"
+      );
+      const footer_inputs = $("#modal-move-files-inputs");
 
       footer_inputs.empty();
-      elements
-        .clone()
-        .attr("type", "hidden")
-        .appendTo(footer_inputs);
+      elements.clone().attr("type", "hidden").appendTo(footer_inputs);
 
-      var target = $("<input />").attr({
+      const target = $("<input />").attr({
         type: "hidden",
         name: "target-folder",
         value: "",
       });
       target.appendTo(footer_inputs);
 
-      var l = document.location;
+      const l = document.location;
       /* don't use document.location + '/json': if anchors in url '/json'
              is ignored, ie http://.../folder#anchor */
       moveFileFillListing(
